@@ -6,12 +6,16 @@ import pathlib
 import re
 import sys
 
-from saltfactories._version import get_versions
+try:
+    from .version import __version__
+except ImportError:
+    from pkg_resources import get_distribution, DistributionNotFound
 
-
-# Store the version attribute
-__version__ = get_versions()["version"]
-del get_versions
+    try:
+        __version__ = get_distribution(__name__).version
+    except DistributionNotFound:
+        # package is not installed
+        __version__ = "0.0.0.not-installed"
 
 # Define __version_info__ attribute
 VERSION_INFO_REGEX = re.compile(
