@@ -7,8 +7,6 @@
 import sys
 from unittest import mock
 
-import pytest
-
 
 def test_skip_if_not_root_skipped(testdir):
     testdir.makepyfile(
@@ -28,14 +26,7 @@ def test_skip_if_not_root_skipped(testdir):
     with mocked_func:
         res = testdir.runpytest()
         res.assert_outcomes(skipped=1)
-    try:
-        res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
-    except AttributeError:  # pragma: no cover
-        # PyTest 4.6.x
-        from _pytest.outcomes import Failed
-
-        with pytest.raises(Failed):
-            res.stdout.fnmatch_lines(["*PytestUnknownMarkWarning*"])
+    res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
 
 
 def test_skip_if_not_root_not_skipped(testdir):
@@ -56,11 +47,4 @@ def test_skip_if_not_root_not_skipped(testdir):
     with mocked_func:
         res = testdir.runpytest_inprocess("-ra", "-vv")
         res.assert_outcomes(passed=1)
-    try:
-        res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
-    except AttributeError:  # pragma: no cover
-        # PyTest 4.6.x
-        from _pytest.outcomes import Failed
-
-        with pytest.raises(Failed):
-            res.stdout.fnmatch_lines(["*PytestUnknownMarkWarning*"])
+    res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
